@@ -18,10 +18,7 @@ class Options:
         # project
         project = subparsers.add_parser("project", help="project related functions")
         project_action = project.add_subparsers(dest="action")
-
-        ## project list
-        project_list = project_action.add_parser("list", help="List all projects")
-        
+       
         ## project pull
         project_pull = project_action.add_parser("pull", help="Pull samples from project")
         project_pull.add_argument(
@@ -30,14 +27,9 @@ class Options:
             help="Name of project"
         )
         project_pull.add_argument(
-            "--approved-only",
-            action="store_true",
-            help="Pull only the approved samples"
-        )
-        project_pull.add_argument(
-            "--labeled-only",
-            action="store_true",
-            help="Pull only the labeled samples"
+            "--format",
+            type=str,
+            help="Output format"
         )
 
         ## project push
@@ -52,11 +44,6 @@ class Options:
             type=str,
             help="Path to image folder"
         )
-        project_push.add_argument(
-            "--label_path",
-            type=str,
-            help="Path to label folder"
-        )
 
         # version
         subparsers.add_parser("version", help="Print current version number")
