@@ -14,41 +14,35 @@ import random
 class ML4visionDataset(Dataset):
     def __init__(
         self,
-        api_key='',
-        name='',
-        owner=None,
-        labeled_only=True,
-        approved_only=False,
+        location="./dataset",
         split='TRAIN',
-        cache_location="./dataset",
-        min_size=None,
+        fake_size=None,
         transform=None,
         mapping=None
     ):
-        client = Client(api_key)
-        project = client.get_project_by_name(name, owner=owner)
-        project.load_samples(labeled_only=labeled_only, approved_only=approved_only, split=split)
 
-        dataset_loc = project.pull(location=cache_location)
+        csv_file = 'train.csv' if split == 'TRAIN' else 'val.csv' 
+        with open(os.path.join(location, csv_file)) as f:
+            data = f.read().splitlines()[1:] 
 
-        self.project = project
-        self.dataset_loc = dataset_loc
-        self.size = len(self.project.samples)
-        self.min_size = min_size
+        self.location = location
+        self.data = data
+        self.size = len(data)
+        self.fake_size = fake_size
         self.transform = transform
         self.mapping = mapping
 
     def __len__(self):
-        return self.min_size or self.size
+        return self.fake_size or self.size
 
     def get_index(self, index):
-        if self.min_size:
+        if self.fake_size:
             index = random.randint(0, self.size - 1) if self.size > 1 else 0
         return index
 
-    def get_image(self, sample):
-        image_filename = sample.asset["filename"]
-        image_path = os.path.join(self.dataset_loc, "images", image_filename)
+    def get_image(self, index):
+        image_filename = self.data[index].split(',')[0]
+        image_path = os.path.join(self.location, image_filename)
         image = load_image(image_path)
         return image
 
@@ -86,9 +80,9 @@ class ObjectDetectionDataset(ML4visionDataset):
 
         return boxes, category_ids
 
-    def get_boxes(self, sample, im_w, im_h):
-        label_filename = os.path.splitext(sample.asset["filename"])[0] + ".json"
-        label_path = os.path.join(self.dataset_loc, "labels", label_filename)
+    def get_boxes(self, index, im_w, im_h):
+        label_filename = self.data[index].split(',')[1]
+        label_path = os.path.join(self.location, label_filename)
         with open(label_path, "r") as f:
             annotations = json.load(f)["annotations"]
         boxes, category_ids = self.format_boxes(annotations, im_w, im_h)
@@ -97,12 +91,11 @@ class ObjectDetectionDataset(ML4visionDataset):
     def __getitem__(self, index):
 
         index = self.get_index(index)
-        sample = self.project.samples[index]
 
-        image = np.array(self.get_image(sample))
+        image = np.array(self.get_image(index))
         im_h, im_w = image.shape[:-1]
 
-        boxes, category_ids = self.get_boxes(sample, im_w, im_h)
+        boxes, category_ids = self.get_boxes(index, im_w, im_h)
 
         if self.transform:
             transformed = self.transform(
@@ -130,9 +123,9 @@ class SegmentationDataset(ML4visionDataset):
         self.ignore_zero = ignore_zero
         print(f"SegmentationDataset created, found {self.size} samples")
 
-    def get_label(self, sample):
-        label_filename = os.path.splitext(sample.asset["filename"])[0] + ".png"
-        label_path = os.path.join(self.dataset_loc, "labels", label_filename)
+    def get_label(self, index):
+        label_filename = self.data[index].split(',')[1]
+        label_path = os.path.join(self.location, label_filename)
         label = np.array(Image.open(label_path))
 
         if self.ignore_zero:
@@ -142,10 +135,9 @@ class SegmentationDataset(ML4visionDataset):
 
     def __getitem__(self, index):
         index = self.get_index(index)
-        sample = self.project.samples[index]
 
-        image = np.array(self.get_image(sample))
-        label = self.get_label(sample)
+        image = np.array(self.get_image(index))
+        label = self.get_label(index)
 
         if self.transform:
             transformed = self.transform(image=image, mask=label)
@@ -168,23 +160,22 @@ class InstanceSegmentationDataset(ML4visionDataset):
         super().__init__(*args, **kwargs)
         print(f"InstanceSegmentationDataset created, found {self.size} samples")
 
-    def get_label(self, sample):
-        cls_filename = os.path.splitext(sample.asset["filename"])[0] + "_cls.png"
-        cls_path = os.path.join(self.dataset_loc, "labels", cls_filename)
+    def get_label(self, index):
+        cls_filename = self.data[index].split(',')[1]
+        cls_path = os.path.join(self.location, cls_filename)
         cls = np.array(Image.open(cls_path))
 
-        inst_filename = os.path.splitext(sample.asset["filename"])[0] + "_inst.png"
-        inst_path = os.path.join(self.dataset_loc, "labels", inst_filename)
+        inst_filename = self.data[index].split(',')[2]
+        inst_path = os.path.join(self.location, inst_filename)
         inst = np.array(Image.open(inst_path))
 
         return cls, inst
 
     def __getitem__(self, index):
         index = self.get_index(index)
-        sample = self.project.samples[index]
 
-        image = np.array(self.get_image(sample))
-        cls_label, inst_label = self.get_label(sample)
+        image = np.array(self.get_image(index))
+        cls_label, inst_label = self.get_label(index)
 
         if self.transform:
             transformed = self.transform(image=image, masks=[cls_label, inst_label])
